====================
Tutorials
====================

Examples shown below may be found in <YOUR_EMBASI_ROOT>/examples/FHIaims.

Basic Embedding Calculation (PBE0-in-PBE)
_________________________________________

.. highlight:: python

We will first demonstrate the use of embedding for a simple methanol dimer. First, using the Atomic Simulation Environment, we may obtain the geometry from the S22 test set




Basis Truncation (PBE0-in-PBE)
______________________________
